AutoExpImageMetadata class

Inheritance

Constructors

AutoExpImageMetadata({required String quality, required int resolution, required int pan, required String metering, required double exposure, required double exposureSpeed, required int shutterLimit, required int analogGainLimit, required double whiteBalanceSpeed, required int rgbGainLimit})

Properties

analogGainLimit → int
final
elapsedTimeMs ↔ int
getter/setter pairinherited
exposure → double
final
exposureSpeed → double
final
hashCode → int
The hash code for this object.
no setterinherited
metering → String
final
pan → int
finalinherited
quality → String
finalinherited
resolution → int
finalinherited
rgbGainLimit → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shutterLimit → int
final
size ↔ int
getter/setter pairinherited
whiteBalanceSpeed → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetaDataList() → List<String>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited