FrameVisionAppState<T extends StatefulWidget> mixin

Superclass constraints

Properties

analogGainLimit ↔ int
getter/setter pair
batteryLevel → int
no setterinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentState ↔ ApplicationState
getter/setter pairinherited
exposure ↔ double
getter/setter pair
exposureSpeed ↔ double
getter/setter pair
frame ↔ BrilliantDevice?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
manualAnalogGain ↔ int
getter/setter pair
manualBlueGain ↔ int
getter/setter pair
manualGreenGain ↔ int
getter/setter pair
manualRedGain ↔ int
getter/setter pair
manualShutter ↔ int
getter/setter pair
meteringIndex ↔ int
getter/setter pair
meteringValues → List<String>
final
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
pan ↔ int
getter/setter pair
qualityIndex ↔ int
getter/setter pair
qualityValues → List<String>
final
resolution ↔ int
getter/setter pair
rgbGainLimit ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shutterLimit ↔ int
getter/setter pair
upright ↔ bool
getter/setter pair
whiteBalanceSpeed ↔ double
getter/setter pair
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
cancel() → Future<void>
cancel tap-listening state and clear the display
override
capture() → Future<(Uint8List, ImageMetadata)>
request a photo from Frame
connectToScannedFrame(BrilliantScannedDevice device) → Future<void>
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
disconnectFrame() → Future<void>
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getBatteryWidget() → Widget
inherited
getCameraDrawer() → Drawer
getFloatingActionButtonWidget(Icon ready, Icon running) → FloatingActionButton?
inherited
getFooterButtonsWidget() → List<Widget>
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCancel() → Future<void>
abstract method that is called at the start of cancel() to give the implementing class a chance to perform some cleanup
onRun() → Future<void>
abstract method that is called at the end of run() to give the implementing class a chance to print some instructions (or perform some other final setup) after the tap handler is hooked up
onTap(int taps) → Future<void>
abstract method that must be implemented by the class mixing in frame_vision_app to capture a photo and perform some action on a 1-, 2-, 3-, n-tap etc.
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
reconnectFrame() → Future<void>
inherited
run() → Future<void>
Implements simple_frame_app run() by listening for taps and handing off to a tapHandler() function in the class that mixes in frame_vision_app. That function would be expected to call capture() and then perform processing on the image
override
scanForFrame() → Future<void>
inherited
scanOrReconnectFrame() → Future<void>
inherited
sendExposureSettings() → Future<void>
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showLoadingScreen() → Future<void>
inherited
startApplication() → Future<void>
the SimpleFrameApp subclass can override with application-specific code if necessary
inherited
stopApplication() → Future<void>
the SimpleFrameApp subclass can override with application-specific code if necessary
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
tryScanAndConnectAndStart({required bool andRun}) → Future<void>
Suitable for inclusion in initState or other startup code, this function will attempt connection, start app (loading Lua, sprites) and optionally call run() (unawaited) to save a few connect/start/(run) steps
inherited
updateAutoExpSettings() → Future<void>
updateManualExpSettings() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited