ImageMetadata class abstract

Implementers

Constructors

ImageMetadata({required String quality, required int resolution, required int pan})

Properties

elapsedTimeMs ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pan → int
final
quality → String
final
resolution → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetaDataList() → List<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited