ManualExpImageMetadata class

Inheritance

Constructors

ManualExpImageMetadata({required String quality, required int resolution, required int pan, required int shutter, required int analogGain, required int redGain, required int greenGain, required int blueGain})

Properties

analogGain → int
final
blueGain → int
final
elapsedTimeMs ↔ int
getter/setter pairinherited
greenGain → int
final
hashCode → int
The hash code for this object.
no setterinherited
pan → int
finalinherited
quality → String
finalinherited
redGain → int
final
resolution → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shutter → int
final
size ↔ int
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetaDataList() → List<String>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited